abacusai.file_connector_instructions — AbacusAI documentation

# abacusai.file_connector_instructions

## Classes

`FileConnectorInstructions` | An object with a full description of the cloud storage bucket authentication options and bucket policy. Returns an error message if the parameters are invalid.

## Module Contents

class abacusai.file_connector_instructions.FileConnectorInstructions(client, verified=None, writePermission=None, authOptions=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An object with a full description of the cloud storage bucket authentication options and bucket policy. Returns an error message if the parameters are invalid.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - verified (bool) – True if the bucket has passed verification

    - writePermission (bool) – True if Abacus.AI has permission to write to this bucket

    - authOptions (list[dict]) – A list of options for giving Abacus.AI access to this bucket

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict